<?php 

/**
 * php solar & lunar calendar v1.0 by Fabrizio Zellini
 *
 * For more info: http://fabrizio.zellini.org/calendario-con-orari-di-alba-e-tramonto-php
 *
 */

/**
 * configuration parameters
 */
$siteBase = "http://fabrizio.zellini.org/calendario";
$calPage ="calendario.php";

$cityName = "Roma";
$cityLat  = 41.91;
$cityLon  = 12.48;

date_default_timezone_set('Europe/Rome');

/* month names in your language **/
$monthNames = array("","Gennaio","Febbraio","Marzo","Aprile","Maggio","Giugno","Luglio","Agosto","Settembre","Ottobre","Novembre","Dicembre");

/** day names in your language  ( monday first ) **/
$dayNames = array("Lunedì","Martedì","Mercoledì","Giovedì","Venerdì","Sabato","Domenica");



function getDescription (){
  global $cityName, $year, $month, $monthNames;
  return "Calendario con orari di alba e tramonto a $cityName nel mese di ".$monthNames[$month]." dell'anno $year";

}

function getH1(){
  global $cityName, $year, $month, $monthNames;
  return "$cityName, calendario con orari di alba e tramonto";

}

function getTitle (){
  global $cityName, $year, $month, $monthNames;

  return "Calendario con orari di alba e tramonto a $cityName";

}

/**
 * end of configuration parameters
 */

require ("moon.php");

function getIntParam ($name,$min,$max,$df) {
  global $_GET;
  if (array_key_exists($name,$_GET)){
    $s = $_GET[$name];
    if (is_numeric($s)){
      $iv = (int) $s;
      if ($iv>=$min && $iv<=$max) return $iv;
    } 
  }
  return $df;
}

// 0 = Monday
function cwday ($wday){
  if( $wday==0 ) return 6; // sunday
  return $wday-1;
}


/** grab year & month, defaulting to current **/

$dt = getdate();
$day=0;

$year=getIntParam ("year",1900,9999,null);
$month=getIntParam ("month",1,12,null);
if (!$month && !$year) {
  $month=$dt['mon']; 
  $year=$dt['year'];
} elseif (!$month){
  $month=1; 
} elseif (!$year){
  $year=$dt['year']; 
} else {
  $day=$dt['mday'];
}


$uCalDate = mktime(12, 0, 0, $month, 1, $year);
// compute prev & next month
if ($month==12){
  $nextmonthlink="year=".($year+1)."&month=1";
} else {
  $nextmonthlink="year=".$year."&month=".($month+1);
}
$nextmonthlink="${siteBase}/${calPage}?".$nextmonthlink;
if ($month==1){
  $prevmonthlink="year=".($year-1)."&month=12";
} else {
  $prevmonthlink="year=".$year."&month=".($month-1);
}
$prevmonthlink = "${siteBase}/${calPage}?".$prevmonthlink;  
$nextyearlink  = "${siteBase}/${calPage}?year=".($year+1)."&month=".$month;
$prevyearlink  = "${siteBase}/${calPage}?year=".($year-1)."&month=".$month;  
?>
<!DOCTYPE html PUBLIC "-//W3C//Dth XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/Dth/xhtml1-transitional.dth">
<html xmlns="http://www.w3.org/1999/xhtml">
  <head>
    <title><?php echo getTitle(); ?></title>
    <link rel="canonical" href="<?= $siteBase ?>" />
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta http-equiv="Content-Language" content="it" />
    <meta name="robots" content="noarchive" />
    <meta name="description" content="<?php echo getDescription(); ?>" />
    <meta name="keywords" content="Calendario, php, alba, tramonto, sole" />

    <meta name="rating" content="General" />

    <link  type="text/css" href="calendario.css" rel="stylesheet" />
    <base href="<?= $siteBase ?>"/>
<?php if (file_exists ("google-analytics-code")) require ("google-analytics-code"); ?>
  </head>
  <body>
<?php 

  $lastday=0;  

  // go back until monday to align day grid
  $uT = $uCalDate;
  while (true){
    $theDate = getdate($uT);
    $wday=cwday($theDate['wday']);
    if ($wday==0) { $uT-=(3600*11);break;}
    $uT-=3600;    
  }
?>

  <div id="container">
    <h1><?php echo getH1(); ?></h1>
    <div id="monthnav">
      <img alt="mese precedente" title="mese precedente" onclick="document.location='<?=$prevmonthlink?>'"  class="navleft" src="<?= $siteBase ?>/img/left-small.png" />
      <h2><?= $monthNames[$month]?></h2>
      <img alt="mese successivo" title="mese successivo" onclick="document.location='<?=$nextmonthlink?>'" class="navright" src="<?= $siteBase ?>/img/right-small.png" />
    </div>
    <div id="yearnav">
      <img alt="anno precedente" title="anno precedente" onclick="document.location='<?=$prevyearlink?>'"  class="navleft" src="<?=$siteBase?>/img/left-small.png" />
      <h3><?= $year ?></h3>
      <img alt="anno successivo" title="anno successivo" onclick="document.location='<?=$nextyearlink?>'" class="navright" src="<?= $siteBase ?>/img/right-small.png" />
    </div>    
    <table id="hmonth">
      <tr id="days">
<?php foreach ($dayNames as $index=>$dayName ) {  ?>        
        <th><?= $dayName?></th><?php }?>
      </tr>
    </table>
    <table id="month">
<?php 
  for ($crow=0;$crow<6;$crow++){
?>
      <tr>
<?php 
    $outmonth=false;
    for ($ccol=0;$ccol<7;$ccol++) {
      $theDate = getdate($uT);
      $year = $theDate['year'];
      $themonth = $theDate['mon'];
      $day = $theDate['mday'];
      
      $isinmonth = $themonth==$month;
      $inmonth= $isinmonth?"inmonth":"outmonth";
      $sunday=$ccol==6?" sunday":"";
      
      $today=($dt['year']==$year && $dt['mon']==$themonth && $dt['mday']==$day)?" today":"";

//  Moon phase
      list($MoonPhase, $MoonAge, $MoonDist, $MoonAng, $SunDist, $SunAng, $mpfrac) = Moon::phase($year, $themonth, $day, 12, 00, 01);
      $moonday = 1+$MoonAge * 29.0 / 29.53058868 ;      
      $moonImg="${siteBase}/img/moonphase/".round($moonday).".png";
?>
      <td class="<?= $inmonth.$sunday.$today?>">
        <div>
<?    if ($isinmonth) {?>        
          <div class="phase"><img src="<?= $moonImg?>"/></div>
<?  // also 1,15 and today display the sun info
        if (true || $day==1 || $day==15 || $today) {
          $sun_info = date_sun_info($uT,  $cityLat, $cityLon); 
          $sunrise = date("H:i", $sun_info['sunrise']);
          $sunset = date("H:i", $sun_info['sunset']);
?>
<div class="sun"><img src="<?= "${siteBase}/img/sole.png" ?>" /><div class="riseset"><?= $sunrise?><br/><?= $sunset?></div></div>
<?
        }
      } else {$outmonth=true;}
?>
          <div class="day"><?= $day ?></div>          
        </div>
      </td>
<?php
      // next day
      while (true) {
        $uT+=3600;  // 1h
        $theDate = getdate($uT);
        if ( $theDate['mday']!=$day) break;
      }
      $uT+(11*3600);
    }
    if ($crow>1 && $outmonth) break;
?>
      </tr>
<?php
  }
?>
    </table>
<?php /* please leave a link to the original post... Thank you! */?>
   <div id="credits">generated by <a href="http://fabrizio.zellini.org/calendario-con-orari-di-alba-e-tramonto-php">Solar php calendar</a></div>
  </div>
  </body>
</html>
